@@ -678,7 +678,7 @@ class BasicPipeline:
     with optional debugging output.
     """
 
-    def  __init__(self, *funcs):
+    def __init__(self, *funcs):
         """
         Parameters
         ----------
@@ -867,6 +867,22 @@ def amap(attr, *args):
     return [getattr(arg, attr) for arg in args]
 
 
+def smap(*x):
+    """Get shape of each array/tensor in a list or tuple.
+
+    Parameters
+    ----------
+    *x: np.arrays or torch.tensors
+        We use star unpacking here to create a consistent interface with amap()
+        and lmap().
+
+    Returns
+    -------
+    list: Shape of each array/tensor in input.
+    """
+    return amap('shape', *x)
+
+
 def identity(x):
     """Returns the input argument. Sometimes it is convenient to have this if
     we sometimes apply a function to an item: rather than defining a None
@@ -1007,6 +1023,53 @@ def spacer(char='-', n_chars=79, newlines_before=1, newlines_after=1):
     return '\n'*newlines_before + char * n_chars + '\n'*newlines_after
 
 
+def snake2camel(text):
+    """Convert snake case to camel case. This assumes the input is valid snake
+    case (if you have some weird hybrid of snake and camel case, for instance,
+    you'd want to do some preprocessing first).
+
+    Parameters
+    ----------
+    text: str
+        Snake case string, e.g. vader_sentiment_score.
+
+    Returns
+    -------
+    str: `text` converted to camel case, e.g. vaderSentimentScore.
+    """
+    res = []
+    prev = ''
+    for char in text:
+        if char != '_':
+            # Check if res is empty because of case with leading underscore.
+            res.append(char.upper() if prev == '_' and res else char)
+        prev = char
+    return ''.join(res)
+
+
+def camel2snake(text):
+    """Convert camel case to snake case. This assumes the input is valid camel
+    case (if you have some weird hybrid of camel and snake case, for instance,
+    you'd want to do some preprocessing first).
+
+    Parameters
+    ----------
+    text: str
+        Camel case string, e.g. vaderSentimentScore.
+
+    Returns
+    -------
+    str: `text` converted to snake case, e.g. vader_sentiment_score.
+    """
+    res = []
+    for char in text:
+        if char.islower():
+            res.append(char)
+        else:
+            res.extend(['_', char.lower()])
+    return ''.join(res)
+
+
 def kwargs_fallback(self, *args, assign=False, **kwargs):
     """Use inside a method that accepts **kwargs. Sometimes we want to use
     an instance variable for some computation but want to give the user the
